"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const utils_1 = require("../../../shared/utils");
const fs = require("fs-extra");
const execSync = require("child_process").execSync;
const replaceInFiles = require('replace-in-files');
const rimraf = require('rimraf');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
// const messages = Messages.loadMessages('fonteva-sfdx', 'org');
class Layouts extends command_1.SfdxCommand {
    static async deployLayouts(packageName, targetUserName) {
        let directory = __dirname + '/../../../../layouts';
        let currentDirectory = process.cwd();
        fs.removeSync(currentDirectory + '/tmp');
        fs.copySync(directory + '/' + packageName, currentDirectory + '/tmp');
        const layoutCommand = `sfdx force:mdapi:deploy -d "${currentDirectory}/tmp/src" --targetusername ${targetUserName} --wait 15`;
        const ns = utils_1.getOrgNamespace(targetUserName);
        if (packageName === 'LightningLens' && ns !== 'LTE') { // this is an LTE dev org
            console.log('LTE Dev org detected - Removing Community Page config from deploy; Community must be configured manually');
            // don't deploy the siteDotCom as it has LTE hard-coded
            const options = {
                files: [
                    'tmp/src/package.xml',
                ],
                from: `<types>
        <members>*</members>
        <name>SiteDotCom</name>
    </types>`,
                to: () => '',
            };
            await replaceInFiles(options);
            rimraf.sync('./tmp/src/siteDotComSites');
        }
        console.log(layoutCommand);
        execSync(layoutCommand, { stdio: [0, 1, 2] });
        fs.removeSync(currentDirectory + '/tmp');
    }
    async run() {
        await Layouts.deployLayouts(this.flags.packagename, this.flags.targetusername);
        return {};
    }
}
Layouts.description = 'Apply useful layouts for Fonteva custom objects.';
Layouts.examples = [
    `$ sfdx install:dependencies --targetusername myOrg@example.com --targetdevhubusername devhub@org.com
  Hello world! This is org: MyOrg and I will be around until Tue Mar 20 2018!
  My hub org id is: 00Dxx000000001234
  `
];
Layouts.args = [];
Layouts.flagsConfig = {
    packagename: command_1.flags.string({ char: 'p', description: 'Package to install layouts for', required: true }),
};
// Comment this out if your command does not require an org username
Layouts.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Layouts.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Layouts.requiresProject = false;
exports.default = Layouts;
//# sourceMappingURL=apply.js.map